#
# spec file for package hpack
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hpack
%bcond_with tests
Name:           %{pkg_name}
Version:        0.33.0
Release:        lp152.1.7
Summary:        A modern format for Haskell packages
License:        MIT
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Glob-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cryptonite-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-infer-license-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-yaml-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-interpolate-devel
BuildRequires:  ghc-mockery-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
A modern format for Haskell packages.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGELOG.md
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGELOG.md

%changelog
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 12 2019 psimons@suse.com
- Update hpack to version 0.33.0.
  [#]# Changes in 0.33.0
  - Support GHC 8.8.1: `fail` is no longer a part of `Monad`. Instead, it lives
    in the `MonadFail` class. Adapting our code to this change meant changing
    the types of exporting functions, unfortunately, hence the major version
    bump.
* Fri Aug 30 2019 psimons@suse.com
- Update hpack to version 0.32.0.
  [#]# Changes in 0.32.0
  - Support Cabal 3.0
  - Switch reexported-modules to comma-separated list
* Mon Mar  4 2019 psimons@suse.com
- Update hpack to version 0.31.2.
  [#]# Changes in 0.31.2
  - Add default value for maintainer (see #339)
  - Escape commas and spaces in filenames when generating cabal files
* Sun Nov  4 2018 psimons@suse.com
- Update hpack to version 0.31.1.
  [#]# Changes in 0.31.1
  - Show the header when printing to stdout (see #331)
  - Add help for `--numeric-version`(see #337)
* Wed Oct 10 2018 psimons@suse.com
- Update hpack to version 0.31.0.
  [#]# Changes in 0.31.0
  - Add `mixin` to the fields read by dependencies when they are
    objects (see #318)
  - `hpack` now returns with a successful exit code if the `.cabal`
    file is up to date, even if it was generated by a newer version of
    `hpack`.
  [#]# Changes in 0.30.0
  - Warn on duplicate fields (see #283)
  - Always render `cabal-version` as `x.y` instead of `>= x.y` so that `cabal
    check` does not complain (see #322)
  - Extend `build-tools` so that it subsumes Cabal's `build-tools` and
    `build-tool-depends` (see #254)
  - Add support for `system-build-tools`
  - Keep declaration order for literal files in c-sources (and other fields
    that accept glob patterns).  This is crucial as a workaround for
    https://ghc.haskell.org/trac/ghc/ticket/13786 (see #324)
* Fri Aug 17 2018 psimons@suse.com
- Update hpack to version 0.29.7.
  [#]# Changes in 0.29.7
  - Expose more stuff from `Hpack.Yaml` so that it can be used by third parties
  [#]# Changes in 0.29.6
  - Add `spec-version` (see #300)
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update hpack to version 0.29.5.
  - Fix a regression related to indentation sniffing (close #310)
  - Desugar ^>= when dependency is a string (see #309)
  - Add support for Apache, MPL and ISC when inferring `license` (see #305)
  - Desugar `^>=` for compatibility with `Cabal < 2` (see #213)
  - Add support for GPL, LGPL and AGPL when inferring `license` (see #305)
  - Add missing `extra-source-files` (see #302)
  - Infer `license` from `license-file`
  - Put the `cabal-version` at the beginning of the generated file. This Is
    required with `cabal-version: 2.1` and higher. (see #292)
  - With `cabal-version: 2.1` or higher omit `>=` when rendering (see #292)
  - Require `cabal-version: 2.2` when SPDX license identifiers are used (see #292)
  - Map cabal-style licenses to SPDX license identifiers when `cabal-version`
    is 2.2 or higher (see #292)
* Mon May 14 2018 psimons@suse.com
- Update hpack to version 0.28.2.
  Relevant changes are:
  - GHC 8.4.1 compatibility
  - Add support for `cxx-options` and `cxx-sources` (see #205)
  - Add support for `data-dir` (see #100)
  - Generate valid `.cabal` files when `verbatim` is used top-level (see #280)
  - Local defaults are now resolved relative to the file they are
    mentioned in, not the CWD that hpack is invoked from.
  - Major refactoring of the exposed API (much cleaner now, but lot's of
    breaking changes!)
  - Remove Git conflict markers before checking the hash of any existing
    `.cabal` files (equivalent to `git checkout --ours`).  This allows to
    regenerate the `.cabal` file on conflicts when rebasing without passing
    `-f` in some cases and helps with preserving the formatting.
  - Allow local files to be used as defaults (#248)
  - Keep non-existing literal files on glob expansion (see #101)
  - Add support for `verbatim` Cabal escape hatch
  - Allow `version` be a numbers
  - Ignore fields that start with an underscore everywhere, not just globally
  - Add support for custom decoders to allow for alternate syntax (e.g. Dhall)
  - `generated-exposed-modules` and `generated-other-modules`, for populating
    the `autogen-modules` field (#207).
  - Corrected `cabal-version` setting for `reexported-modules` inside
    a conditional.
  - Add support for `defaults`
  - Add `--numeric-version`
  - Add support for `signatures`
  - `extra-doc-files` requires setting `cabal-version` to at least
    1.18; this is now done properly.
  - Accept bool for `condition` (see #230)
  - Fix a bug in module inference for conditionals (see #236)
  - Add support for `extra-doc-files`.
  - Add support for `pkg-config-dependencies`
  - Allow dependency constraints to be numbers (see #234)
  - Accept section-specific fields in conditionals (see #175, thanks to Scott
    Fleischman)
  - New section: `internal-libraries`, for Cabal 2's internal libraries (see #200).
  - Do not overwrite any existing cabal file if it has been modified manually
  - Add support for `frameworks` and `extra-frameworks-dirs`
  - Compatibility with `Glob >= 0.9.0`
  - Add `IsList` instance for `Dependencies`
  - Add Paths_* module to executables (see #195, for GHC 8.2.1 compatibility)
  - Allow specifying dependencies as a hash (see #198)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.18.1.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 0.17.1.
* Fri Apr  7 2017 psimons@suse.com
- Improve generated package %%description.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.17.0 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 0.14.1 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.14.1 revision 0 with cabal2obs.
* Sat Jun 11 2016 mimi.vx@gmail.com
- update to 0.14.1
* Mon May 23 2016 mimi.vx@gmail.com
- initial commit
